**UniLoaders** is a langchain based script that aims to solve any type of data ingestion within a single package. The formats currently supported are the following:
1. URLs
2. Microsoft Word Documents
3. Microsoft Powerpoints
4. PDFs
5. JPGs
6. PNGs

# One Install

```pip install UniLoaders```


# One Function

If you have a URL, enter it as a string. 
For files enter the path to the file as a string.

```python

def all_loaders(path: str)

```

